@@ -27,7 +27,6 @@ TEST_SUFFIX = re.compile(r"(Test|_test)$")
 # NOTE: much of the high level "replace default output bits" approach is
 # cribbed directly from pytest-sugar at 0.8.0
 class RelaxedReporter(TerminalReporter):
-
     def __init__(self, builtin):
         # Pass in the builtin reporter's config so we're not redoing all of its
         # initial setup/cli parsing/etc. NOTE: TerminalReporter is old-style :(
@@ -86,7 +85,7 @@ class RelaxedReporter(TerminalReporter):
     def split(self, id_):
         # Split on pytest's :: joiner, and strip out our intermediate
         # SpecInstance objects (appear as '()')
-        headers = [x for x in id_.split("::")[1:] if x != "()"]
+        headers = [x for x in id_.split("::")[1:]]
         # Last one is the actual test being reported on, not a header
         leaf = headers.pop()
         return headers, leaf
